@@ -165,6 +165,8 @@ struct VideoSettings {
 /// Main connection and controller for the drone
 #[derive(Debug)]
 pub struct Drone {
+    peer_ip: String,
+
     socket: UdpSocket,
     video_socket: Option<UdpSocket>,
     video: VideoSettings,
@@ -352,6 +354,7 @@ impl Drone {
     /// drone.take_off();
     /// ```
     pub fn new(ip: &str) -> Drone {
+        let peer_ip = ip.to_string();
         let socket = UdpSocket::bind(&SocketAddr::from(([0, 0, 0, 0], 8889)))
             .expect("couldn't bind to command address");
         socket.set_nonblocking(true).unwrap();
@@ -370,6 +373,7 @@ impl Drone {
         let drone_meta = DroneMeta::default();
 
         Drone {
+            peer_ip,
             socket,
             video_socket: None,
             video,
@@ -380,10 +384,6 @@ impl Drone {
         }
     }
 
-    pub fn command_mode(self) -> CommandMode {
-        CommandMode::from(self.socket)
-    }
-
     /// Connect to the drone and inform the drone on with port you are ready to receive the video-stream
     ///
     /// The Video stream do not start automatically. You have to start it with
@@ -544,6 +544,18 @@ impl Drone {
     }
 }
 
+impl Drone {
+    /// You can switch the drone to the command mode.
+    /// To get back to the "Free-Flight-Mode" you have to reboot the drone.
+    ///
+    /// In the CommandMode you can move the drone by cm in the 3D space
+    /// If you are using tokio as executer, use the `tokio_async` feature
+    /// to prevent the executer from being blocked.
+    pub fn command_mode(self) -> CommandMode {
+        CommandMode::from(self.peer_ip.parse::<SocketAddr>().unwrap())
+    }
+}
+
 impl Drone {
     pub fn take_off(&self) -> Result {
         self.send(UdpCommand::new(CommandIds::TakeoffCmd, PackageTypes::X68))
